import { diffJson } from 'diff';
import colors from 'colors';
import os from 'os';
export var stringifyError = function stringifyError(error) {
  return error == null ? 'no error' : error.toString();
};
export var stringifyDiff = function stringifyDiff(expected, result) {
  return diffJson(expected, result, {
    undefinedReplacement: '<undefined>'
  }).map(function (change) {
    var color = colors.gray;
    var prefix = '';

    if (change.added) {
      color = colors.green;
      prefix = '+';
    } else if (change.removed) {
      color = colors.red;
      prefix = '-';
    }

    return color("" + prefix + change.value);
  }).join('');
};

var isExecutedSideEffect = function isExecutedSideEffect(value) {
  return Array.isArray(value) && value.length > 0 && typeof value[0] === 'string';
};

export function stringify(item) {
  if (isExecutedSideEffect(item)) {
    var name = item[0],
        args = item.slice(1);
    return name + "(" + args.map(function (arg) {
      return JSON.stringify(arg);
    }).join(',') + ")";
  }

  return JSON.stringify(item, null, 2);
}

var stringifyShouldExecuteFailure = function stringifyShouldExecuteFailure(name, expected, executed) {
  return name + " assertion failed:" + colors.green(os.EOL + "Expected:" + os.EOL + stringify(expected)) + os.EOL + "Executed:" + os.EOL + executed.map(function (executedItem, index) {
    return colors.red("#" + index + ":" + os.EOL + stringify(executedItem));
  }).join(os.EOL);
};

export var stringifyShouldExecuteCommandFailure = function stringifyShouldExecuteCommandFailure(expectedCommand, executedCommands) {
  return stringifyShouldExecuteFailure('shouldExecuteCommand', expectedCommand, executedCommands);
};
export var stringifyShouldExecuteQueryFailure = function stringifyShouldExecuteQueryFailure(expectedQuery, executedQueries) {
  return stringifyShouldExecuteFailure('shouldExecuteQuery', expectedQuery, executedQueries);
};
export var stringifyShouldExecuteSideEffectFailure = function stringifyShouldExecuteSideEffectFailure(expectedSideEffect, executedSideEffects) {
  return stringifyShouldExecuteFailure('shouldExecuteSideEffect', expectedSideEffect, executedSideEffects);
};
//# sourceMappingURL=format.js.map